@@ -3,7 +3,7 @@ from typing import Optional
 
 from sqlalchemy.engine import Dialect
 from sqlalchemy.sql.sqltypes import Numeric
-from sqlalchemy.types import TypeDecorator, NUMERIC
+from sqlalchemy.types import NUMERIC, TypeDecorator
 
 from atlantiscore.types.evm import EVMAddress as PythonEVMAddress, LiteralEVMAddress
 
